@@ -8,8 +8,6 @@ from lunar.lunar_client import LunarClient, LunarError
 from lunar.data.datasets.models import Dataset, DatasetPutIn, DatasetPatchIn
 from lunar.data.datasets.models.params import PARAMS, PARAMS_PATCH
 
-LUNAR_DATA_DATASETS_API_URL = "/v1/datasets"
-
 
 loop = asyncio.get_event_loop()
 
@@ -30,8 +28,6 @@ class DatasetClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = LUNAR_DATA_DATASETS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_DATA_DATASETS_API_URL}"
-
     async def create_dataset_async(self, id: str, data_type: str, params: Dict[str, Any]) -> Dataset:
         """
         Create a new dataset (async).
@@ -73,7 +69,7 @@ class DatasetClient(LunarClient):
         except ValidationError as e:
             raise LunarError(code=400, msg=str(e))
 
-        body = await self._request(method="POST", url=self.api_url, data=dataset.dict())
+        body = await self._request(method="POST", url=self.config.API_PATH, data=dataset.dict())
         return Dataset[PARAMS[data_type]](**body["data"])
 
     def create_dataset(self, id: str, data_type: str, params: Dict[str, Any]) -> Dataset:
@@ -124,7 +120,7 @@ class DatasetClient(LunarClient):
         ```
         """
 
-        body = await self._request(method="GET", url=self.api_url)
+        body = await self._request(method="GET", url=self.config.API_PATH)
 
         return [Dataset(**dataset) for dataset in body["data"]]
 
@@ -162,7 +158,7 @@ class DatasetClient(LunarClient):
         ```
         """
 
-        body = await self._request(method="GET", url=f"{self.api_url}/{id}")
+        body = await self._request(method="GET", url=f"{self.config.API_PATH}/{id}")
         return Dataset(**body["data"])
 
     def get_dataset(self, id: str) -> Dataset:
@@ -227,7 +223,7 @@ class DatasetClient(LunarClient):
         except ValidationError as e:
             raise LunarError(code=400, msg=str(e))
 
-        body = await self._request(method="PUT", url=f"{self.api_url}/{id}", data=updated_dataset.dict())
+        body = await self._request(method="PUT", url=f"{self.config.API_PATH}/{id}", data=updated_dataset.dict())
         return Dataset[PARAMS[data_type]](**body["data"])
 
     def update_dataset(self, id: str, data_type: str, params: Dict[str, Any]) -> Dataset:
@@ -295,7 +291,7 @@ class DatasetClient(LunarClient):
         patched_dataset = DatasetPatchIn[PARAMS_PATCH[data_type]](**request_body)
 
         body = await self._request(
-            method="PATCH", url=f"{self.api_url}/{id}", data=patched_dataset.dict(exclude_none=True)
+            method="PATCH", url=f"{self.config.API_PATH}/{id}", data=patched_dataset.dict(exclude_none=True)
         )
         return Dataset(**body["data"])
 
@@ -340,7 +336,7 @@ class DatasetClient(LunarClient):
         ```
         """
 
-        return await self._request(method="DELETE", url=f"{self.api_url}/{id}")
+        return await self._request(method="DELETE", url=f"{self.config.API_PATH}/{id}")
 
     def delete_dataset(self, id: str) -> None:
         """
